==> kst_1.0.0.orig.tar.gz: kst-1.0.0/kst/kst/kstplotbase.cpp <==
/***************************************************************************
                              kstplotbase.cpp
                             -----------------
    begin                : Mar 28, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kstplotbase.h"


KstPlotBase::KstPlotBase(const QString& type) : KstMetaPlot(type) {
}


KstPlotBase::KstPlotBase(QDomElement& e) : KstMetaPlot(e) {
}


KstPlotBase::~KstPlotBase() {
}


KstObject::UpdateType KstPlotBase::update() {
  return NO_CHANGE;
}


void KstPlotBase::save(QTextStream& ts, const QString& indent) {
  KstMetaPlot::save(ts, indent);
}


void KstPlotBase::paint(KstPaintType type, QPainter& p) {
  KstMetaPlot::paint(type, p);
}

#include "kstplotbase.moc"
// vim: ts=2 sw=2 et

==> kst_1.1.1.orig.tar.gz: kst-1.1.1/kst/kst/kstplotbase.cpp <==
/***************************************************************************
                              kstplotbase.cpp
                             -----------------
    begin                : Mar 28, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kstplotbase.h"


KstPlotBase::KstPlotBase(const QString& type) : KstMetaPlot(type) {
}


KstPlotBase::KstPlotBase(const QDomElement& e) : KstMetaPlot(e) {
}


KstPlotBase::KstPlotBase(const KstPlotBase& plotBase) : KstMetaPlot(plotBase) {
}


KstPlotBase::~KstPlotBase() {
}


void KstPlotBase::save(QTextStream& ts, const QString& indent) {
  KstMetaPlot::save(ts, indent);
}


void KstPlotBase::paint(KstPaintType type, QPainter& p) {
  KstMetaPlot::paint(type, p);
}

#include "kstplotbase.moc"
// vim: ts=2 sw=2 et
